from antlr4 import *
from .grammar.PBXProjLexer import PBXProjLexer
from .grammar.PBXProjParser import PBXProjParser
from .kin_error_listener import KinErrorListener


class Verifier:
    def check_errors(self, path):
        parser, error_listener = self.create_parser(path)
        tree = parser.start()
        return error_listener.errors

    def create_parser(self, path):
        file = FileStream(path, "utf-8")
        lexer = PBXProjLexer(file)
        stream = CommonTokenStream(lexer)
        error_listener = KinErrorListener()
        parser = PBXProjParser(stream)
        parser._listeners = [error_listener]
        return parser, error_listener



#!/usr/bin/env python

import sys
import os
from .verifier import Verifier
from .grammar.PBXProjLexer import PBXProjLexer
from .grammar.PBXProjParser import PBXProjParser


def check_errors(file):
    verifier = Verifier()
    errors = verifier.check_errors(file)
    return errors


def find_target_files():
    target_files = []

    if len(sys.argv) == 2:
        target_files.append(sys.argv[1])
    else:
        for f in os.listdir(os.getcwd()):
            if f.endswith(".xcodeproj"):
                target_files.append(os.path.join(f, "project.pbxproj"))

    return target_files


def print_help():
    print(("USAGE: kin [file]\n" +
          "DESCRIPTION: Verifies the correctness of your project.pbxproj " +
          "file. If no arguments are supplied, Kin will try to find a " +
          "project.pbxproj file in the current project.\nARGUMENTS:\n" +
          "\t- file\tOptionally provides the location of your " +
          "project.pbxproj file"))


def assert_valid_target_files(target_files):
    if len(target_files) == 0:
        print(("ERROR: Unable to find project.pbxproj " +
              "file in the current directory\n"))
        print_help()
        sys.exit(-2)
    elif len(target_files) > 1:
        print(("ERROR: Too many project.pbxproj files: " +
              str(target_files) + ". Remember you can call Kin with a " +
              "parameter to specify the file you want to verify, i.e. \"kin " +
              str(target_files[0]) + "\"\n"))
        print_help()
        sys.exit(-3)


def assert_no_errors(errors):
    if errors:
        sys.exit(-1)


def print_verification_result(errors):
    if errors:
        for error in errors:
            print(("ERROR: " + error))
    else:
        print("CORRECT")


def main():
    target_files = find_target_files()
    assert_valid_target_files(target_files)

    target_file = target_files[0]
    errors = check_errors(target_file)
    print_verification_result(errors)
    assert_no_errors(errors)


if __name__ == '__main__':
    main()



from antlr4.error.ErrorListener import ErrorListener


class KinErrorListener(ErrorListener):
    def __init__(self):
        self.errors = []

    def syntaxError(self, recognizer, offendingSymbol, line, column, msg, e):
        self.errors.append("line " + str(line) + ":" + str(column) + " " + msg)



import sys
from codecs import open
from os import path

from setuptools import find_packages, setup

if sys.version_info.major < 3:
    raise RuntimeError('Please use python3 to install this package')

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='kin',
    version='2.1.1',
    description='A simple project.pbxproj verifier',
    long_description=long_description,
    url='https://github.com/Serchinastico/Kin',
    author='Serchinastico',
    author_email='oss@serchinastico.com',
    license='Apache Software',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
    ],

    keywords='xcode project.pbxproj lint objective-c swift ios',
    packages=find_packages(exclude=['tests']),
    install_requires=[
        'argparse==1.4.0',
        'antlr4-python3-runtime==4.11.1'
    ],
    entry_points={
        'console_scripts': [
            'kin = kin.kin:main',
        ],
    },
)



# Generated from PBXProj.g4 by ANTLR 4.11.1
from antlr4 import *
if __name__ is not None and "." in __name__:
    from .PBXProjParser import PBXProjParser
else:
    from PBXProjParser import PBXProjParser

# This class defines a complete listener for a parse tree produced by PBXProjParser.
class PBXProjListener(ParseTreeListener):

    # Enter a parse tree produced by PBXProjParser#start.
    def enterStart(self, ctx:PBXProjParser.StartContext):
        pass

    # Exit a parse tree produced by PBXProjParser#start.
    def exitStart(self, ctx:PBXProjParser.StartContext):
        pass


    # Enter a parse tree produced by PBXProjParser#root_element.
    def enterRoot_element(self, ctx:PBXProjParser.Root_elementContext):
        pass

    # Exit a parse tree produced by PBXProjParser#root_element.
    def exitRoot_element(self, ctx:PBXProjParser.Root_elementContext):
        pass


    # Enter a parse tree produced by PBXProjParser#archive_version.
    def enterArchive_version(self, ctx:PBXProjParser.Archive_versionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#archive_version.
    def exitArchive_version(self, ctx:PBXProjParser.Archive_versionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#classes.
    def enterClasses(self, ctx:PBXProjParser.ClassesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#classes.
    def exitClasses(self, ctx:PBXProjParser.ClassesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#object_version.
    def enterObject_version(self, ctx:PBXProjParser.Object_versionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#object_version.
    def exitObject_version(self, ctx:PBXProjParser.Object_versionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#objects.
    def enterObjects(self, ctx:PBXProjParser.ObjectsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#objects.
    def exitObjects(self, ctx:PBXProjParser.ObjectsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#root_object.
    def enterRoot_object(self, ctx:PBXProjParser.Root_objectContext):
        pass

    # Exit a parse tree produced by PBXProjParser#root_object.
    def exitRoot_object(self, ctx:PBXProjParser.Root_objectContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_aggregate_target_section.
    def enterPbx_aggregate_target_section(self, ctx:PBXProjParser.Pbx_aggregate_target_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_aggregate_target_section.
    def exitPbx_aggregate_target_section(self, ctx:PBXProjParser.Pbx_aggregate_target_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_build_file_section.
    def enterPbx_build_file_section(self, ctx:PBXProjParser.Pbx_build_file_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_build_file_section.
    def exitPbx_build_file_section(self, ctx:PBXProjParser.Pbx_build_file_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_container_item_proxy_section.
    def enterPbx_container_item_proxy_section(self, ctx:PBXProjParser.Pbx_container_item_proxy_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_container_item_proxy_section.
    def exitPbx_container_item_proxy_section(self, ctx:PBXProjParser.Pbx_container_item_proxy_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_copy_files_build_phase_section.
    def enterPbx_copy_files_build_phase_section(self, ctx:PBXProjParser.Pbx_copy_files_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_copy_files_build_phase_section.
    def exitPbx_copy_files_build_phase_section(self, ctx:PBXProjParser.Pbx_copy_files_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_file_reference_section.
    def enterPbx_file_reference_section(self, ctx:PBXProjParser.Pbx_file_reference_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_file_reference_section.
    def exitPbx_file_reference_section(self, ctx:PBXProjParser.Pbx_file_reference_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_frameworks_build_phase_section.
    def enterPbx_frameworks_build_phase_section(self, ctx:PBXProjParser.Pbx_frameworks_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_frameworks_build_phase_section.
    def exitPbx_frameworks_build_phase_section(self, ctx:PBXProjParser.Pbx_frameworks_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_group_section.
    def enterPbx_group_section(self, ctx:PBXProjParser.Pbx_group_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_group_section.
    def exitPbx_group_section(self, ctx:PBXProjParser.Pbx_group_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_headers_build_phase_section.
    def enterPbx_headers_build_phase_section(self, ctx:PBXProjParser.Pbx_headers_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_headers_build_phase_section.
    def exitPbx_headers_build_phase_section(self, ctx:PBXProjParser.Pbx_headers_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_native_target_section.
    def enterPbx_native_target_section(self, ctx:PBXProjParser.Pbx_native_target_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_native_target_section.
    def exitPbx_native_target_section(self, ctx:PBXProjParser.Pbx_native_target_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_legacy_target_section.
    def enterPbx_legacy_target_section(self, ctx:PBXProjParser.Pbx_legacy_target_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_legacy_target_section.
    def exitPbx_legacy_target_section(self, ctx:PBXProjParser.Pbx_legacy_target_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_project_section.
    def enterPbx_project_section(self, ctx:PBXProjParser.Pbx_project_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_project_section.
    def exitPbx_project_section(self, ctx:PBXProjParser.Pbx_project_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_reference_proxy_section.
    def enterPbx_reference_proxy_section(self, ctx:PBXProjParser.Pbx_reference_proxy_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_reference_proxy_section.
    def exitPbx_reference_proxy_section(self, ctx:PBXProjParser.Pbx_reference_proxy_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_resources_build_phase_section.
    def enterPbx_resources_build_phase_section(self, ctx:PBXProjParser.Pbx_resources_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_resources_build_phase_section.
    def exitPbx_resources_build_phase_section(self, ctx:PBXProjParser.Pbx_resources_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_shell_script_build_phase_section.
    def enterPbx_shell_script_build_phase_section(self, ctx:PBXProjParser.Pbx_shell_script_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_shell_script_build_phase_section.
    def exitPbx_shell_script_build_phase_section(self, ctx:PBXProjParser.Pbx_shell_script_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_sources_build_phase_section.
    def enterPbx_sources_build_phase_section(self, ctx:PBXProjParser.Pbx_sources_build_phase_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_sources_build_phase_section.
    def exitPbx_sources_build_phase_section(self, ctx:PBXProjParser.Pbx_sources_build_phase_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_target_dependency_section.
    def enterPbx_target_dependency_section(self, ctx:PBXProjParser.Pbx_target_dependency_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_target_dependency_section.
    def exitPbx_target_dependency_section(self, ctx:PBXProjParser.Pbx_target_dependency_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_variant_group_section.
    def enterPbx_variant_group_section(self, ctx:PBXProjParser.Pbx_variant_group_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_variant_group_section.
    def exitPbx_variant_group_section(self, ctx:PBXProjParser.Pbx_variant_group_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_build_configuration_section.
    def enterXc_build_configuration_section(self, ctx:PBXProjParser.Xc_build_configuration_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_build_configuration_section.
    def exitXc_build_configuration_section(self, ctx:PBXProjParser.Xc_build_configuration_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_configuration_list_section.
    def enterXc_configuration_list_section(self, ctx:PBXProjParser.Xc_configuration_list_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_configuration_list_section.
    def exitXc_configuration_list_section(self, ctx:PBXProjParser.Xc_configuration_list_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_remote_swift_package_reference_section.
    def enterXc_remote_swift_package_reference_section(self, ctx:PBXProjParser.Xc_remote_swift_package_reference_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_remote_swift_package_reference_section.
    def exitXc_remote_swift_package_reference_section(self, ctx:PBXProjParser.Xc_remote_swift_package_reference_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_swift_package_product_dependency_section.
    def enterXc_swift_package_product_dependency_section(self, ctx:PBXProjParser.Xc_swift_package_product_dependency_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_swift_package_product_dependency_section.
    def exitXc_swift_package_product_dependency_section(self, ctx:PBXProjParser.Xc_swift_package_product_dependency_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_version_group_section.
    def enterXc_version_group_section(self, ctx:PBXProjParser.Xc_version_group_sectionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_version_group_section.
    def exitXc_version_group_section(self, ctx:PBXProjParser.Xc_version_group_sectionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_aggregate_target.
    def enterPbx_aggregate_target(self, ctx:PBXProjParser.Pbx_aggregate_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_aggregate_target.
    def exitPbx_aggregate_target(self, ctx:PBXProjParser.Pbx_aggregate_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_build_file.
    def enterPbx_build_file(self, ctx:PBXProjParser.Pbx_build_fileContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_build_file.
    def exitPbx_build_file(self, ctx:PBXProjParser.Pbx_build_fileContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_container_item_proxy.
    def enterPbx_container_item_proxy(self, ctx:PBXProjParser.Pbx_container_item_proxyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_container_item_proxy.
    def exitPbx_container_item_proxy(self, ctx:PBXProjParser.Pbx_container_item_proxyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_copy_files_build_phase.
    def enterPbx_copy_files_build_phase(self, ctx:PBXProjParser.Pbx_copy_files_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_copy_files_build_phase.
    def exitPbx_copy_files_build_phase(self, ctx:PBXProjParser.Pbx_copy_files_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_file_reference.
    def enterPbx_file_reference(self, ctx:PBXProjParser.Pbx_file_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_file_reference.
    def exitPbx_file_reference(self, ctx:PBXProjParser.Pbx_file_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_frameworks_build_phase.
    def enterPbx_frameworks_build_phase(self, ctx:PBXProjParser.Pbx_frameworks_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_frameworks_build_phase.
    def exitPbx_frameworks_build_phase(self, ctx:PBXProjParser.Pbx_frameworks_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_group.
    def enterPbx_group(self, ctx:PBXProjParser.Pbx_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_group.
    def exitPbx_group(self, ctx:PBXProjParser.Pbx_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_headers_build_phase.
    def enterPbx_headers_build_phase(self, ctx:PBXProjParser.Pbx_headers_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_headers_build_phase.
    def exitPbx_headers_build_phase(self, ctx:PBXProjParser.Pbx_headers_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_native_target.
    def enterPbx_native_target(self, ctx:PBXProjParser.Pbx_native_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_native_target.
    def exitPbx_native_target(self, ctx:PBXProjParser.Pbx_native_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_legacy_target.
    def enterPbx_legacy_target(self, ctx:PBXProjParser.Pbx_legacy_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_legacy_target.
    def exitPbx_legacy_target(self, ctx:PBXProjParser.Pbx_legacy_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_project.
    def enterPbx_project(self, ctx:PBXProjParser.Pbx_projectContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_project.
    def exitPbx_project(self, ctx:PBXProjParser.Pbx_projectContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_reference_proxy.
    def enterPbx_reference_proxy(self, ctx:PBXProjParser.Pbx_reference_proxyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_reference_proxy.
    def exitPbx_reference_proxy(self, ctx:PBXProjParser.Pbx_reference_proxyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_resources_build_phase.
    def enterPbx_resources_build_phase(self, ctx:PBXProjParser.Pbx_resources_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_resources_build_phase.
    def exitPbx_resources_build_phase(self, ctx:PBXProjParser.Pbx_resources_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_shell_script_build_phase.
    def enterPbx_shell_script_build_phase(self, ctx:PBXProjParser.Pbx_shell_script_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_shell_script_build_phase.
    def exitPbx_shell_script_build_phase(self, ctx:PBXProjParser.Pbx_shell_script_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_sources_build_phase.
    def enterPbx_sources_build_phase(self, ctx:PBXProjParser.Pbx_sources_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_sources_build_phase.
    def exitPbx_sources_build_phase(self, ctx:PBXProjParser.Pbx_sources_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_target_dependency.
    def enterPbx_target_dependency(self, ctx:PBXProjParser.Pbx_target_dependencyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_target_dependency.
    def exitPbx_target_dependency(self, ctx:PBXProjParser.Pbx_target_dependencyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pbx_variant_group.
    def enterPbx_variant_group(self, ctx:PBXProjParser.Pbx_variant_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pbx_variant_group.
    def exitPbx_variant_group(self, ctx:PBXProjParser.Pbx_variant_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_build_configuration.
    def enterXc_build_configuration(self, ctx:PBXProjParser.Xc_build_configurationContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_build_configuration.
    def exitXc_build_configuration(self, ctx:PBXProjParser.Xc_build_configurationContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_configuration_list.
    def enterXc_configuration_list(self, ctx:PBXProjParser.Xc_configuration_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_configuration_list.
    def exitXc_configuration_list(self, ctx:PBXProjParser.Xc_configuration_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_remote_swift_package_reference.
    def enterXc_remote_swift_package_reference(self, ctx:PBXProjParser.Xc_remote_swift_package_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_remote_swift_package_reference.
    def exitXc_remote_swift_package_reference(self, ctx:PBXProjParser.Xc_remote_swift_package_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_swift_package_product_dependency.
    def enterXc_swift_package_product_dependency(self, ctx:PBXProjParser.Xc_swift_package_product_dependencyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_swift_package_product_dependency.
    def exitXc_swift_package_product_dependency(self, ctx:PBXProjParser.Xc_swift_package_product_dependencyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_version_group.
    def enterXc_version_group(self, ctx:PBXProjParser.Xc_version_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_version_group.
    def exitXc_version_group(self, ctx:PBXProjParser.Xc_version_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_aggregate_target.
    def enterIsa_pbx_aggregate_target(self, ctx:PBXProjParser.Isa_pbx_aggregate_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_aggregate_target.
    def exitIsa_pbx_aggregate_target(self, ctx:PBXProjParser.Isa_pbx_aggregate_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_build_file.
    def enterIsa_pbx_build_file(self, ctx:PBXProjParser.Isa_pbx_build_fileContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_build_file.
    def exitIsa_pbx_build_file(self, ctx:PBXProjParser.Isa_pbx_build_fileContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_container_item_proxy.
    def enterIsa_pbx_container_item_proxy(self, ctx:PBXProjParser.Isa_pbx_container_item_proxyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_container_item_proxy.
    def exitIsa_pbx_container_item_proxy(self, ctx:PBXProjParser.Isa_pbx_container_item_proxyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_copy_files_build_phase.
    def enterIsa_pbx_copy_files_build_phase(self, ctx:PBXProjParser.Isa_pbx_copy_files_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_copy_files_build_phase.
    def exitIsa_pbx_copy_files_build_phase(self, ctx:PBXProjParser.Isa_pbx_copy_files_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_file_reference.
    def enterIsa_pbx_file_reference(self, ctx:PBXProjParser.Isa_pbx_file_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_file_reference.
    def exitIsa_pbx_file_reference(self, ctx:PBXProjParser.Isa_pbx_file_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_frameworks_build_phase.
    def enterIsa_pbx_frameworks_build_phase(self, ctx:PBXProjParser.Isa_pbx_frameworks_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_frameworks_build_phase.
    def exitIsa_pbx_frameworks_build_phase(self, ctx:PBXProjParser.Isa_pbx_frameworks_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_group.
    def enterIsa_pbx_group(self, ctx:PBXProjParser.Isa_pbx_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_group.
    def exitIsa_pbx_group(self, ctx:PBXProjParser.Isa_pbx_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_header_build_phase.
    def enterIsa_pbx_header_build_phase(self, ctx:PBXProjParser.Isa_pbx_header_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_header_build_phase.
    def exitIsa_pbx_header_build_phase(self, ctx:PBXProjParser.Isa_pbx_header_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_native_target.
    def enterIsa_pbx_native_target(self, ctx:PBXProjParser.Isa_pbx_native_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_native_target.
    def exitIsa_pbx_native_target(self, ctx:PBXProjParser.Isa_pbx_native_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_legacy_target.
    def enterIsa_pbx_legacy_target(self, ctx:PBXProjParser.Isa_pbx_legacy_targetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_legacy_target.
    def exitIsa_pbx_legacy_target(self, ctx:PBXProjParser.Isa_pbx_legacy_targetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_project.
    def enterIsa_pbx_project(self, ctx:PBXProjParser.Isa_pbx_projectContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_project.
    def exitIsa_pbx_project(self, ctx:PBXProjParser.Isa_pbx_projectContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_reference_proxy.
    def enterIsa_pbx_reference_proxy(self, ctx:PBXProjParser.Isa_pbx_reference_proxyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_reference_proxy.
    def exitIsa_pbx_reference_proxy(self, ctx:PBXProjParser.Isa_pbx_reference_proxyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_resources_build_phase.
    def enterIsa_pbx_resources_build_phase(self, ctx:PBXProjParser.Isa_pbx_resources_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_resources_build_phase.
    def exitIsa_pbx_resources_build_phase(self, ctx:PBXProjParser.Isa_pbx_resources_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_shell_script_build_phase.
    def enterIsa_pbx_shell_script_build_phase(self, ctx:PBXProjParser.Isa_pbx_shell_script_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_shell_script_build_phase.
    def exitIsa_pbx_shell_script_build_phase(self, ctx:PBXProjParser.Isa_pbx_shell_script_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_sources_build_phase.
    def enterIsa_pbx_sources_build_phase(self, ctx:PBXProjParser.Isa_pbx_sources_build_phaseContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_sources_build_phase.
    def exitIsa_pbx_sources_build_phase(self, ctx:PBXProjParser.Isa_pbx_sources_build_phaseContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_target_dependency.
    def enterIsa_pbx_target_dependency(self, ctx:PBXProjParser.Isa_pbx_target_dependencyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_target_dependency.
    def exitIsa_pbx_target_dependency(self, ctx:PBXProjParser.Isa_pbx_target_dependencyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_pbx_variant_group.
    def enterIsa_pbx_variant_group(self, ctx:PBXProjParser.Isa_pbx_variant_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_pbx_variant_group.
    def exitIsa_pbx_variant_group(self, ctx:PBXProjParser.Isa_pbx_variant_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_xc_build_configuration.
    def enterIsa_xc_build_configuration(self, ctx:PBXProjParser.Isa_xc_build_configurationContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_xc_build_configuration.
    def exitIsa_xc_build_configuration(self, ctx:PBXProjParser.Isa_xc_build_configurationContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_xc_configuration_list.
    def enterIsa_xc_configuration_list(self, ctx:PBXProjParser.Isa_xc_configuration_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_xc_configuration_list.
    def exitIsa_xc_configuration_list(self, ctx:PBXProjParser.Isa_xc_configuration_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_xc_remote_swift_package_reference.
    def enterIsa_xc_remote_swift_package_reference(self, ctx:PBXProjParser.Isa_xc_remote_swift_package_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_xc_remote_swift_package_reference.
    def exitIsa_xc_remote_swift_package_reference(self, ctx:PBXProjParser.Isa_xc_remote_swift_package_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_xc_swift_package_product_dependency.
    def enterIsa_xc_swift_package_product_dependency(self, ctx:PBXProjParser.Isa_xc_swift_package_product_dependencyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_xc_swift_package_product_dependency.
    def exitIsa_xc_swift_package_product_dependency(self, ctx:PBXProjParser.Isa_xc_swift_package_product_dependencyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#isa_xc_version_group.
    def enterIsa_xc_version_group(self, ctx:PBXProjParser.Isa_xc_version_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#isa_xc_version_group.
    def exitIsa_xc_version_group(self, ctx:PBXProjParser.Isa_xc_version_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#file_ref.
    def enterFile_ref(self, ctx:PBXProjParser.File_refContext):
        pass

    # Exit a parse tree produced by PBXProjParser#file_ref.
    def exitFile_ref(self, ctx:PBXProjParser.File_refContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_ref.
    def enterProduct_ref(self, ctx:PBXProjParser.Product_refContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_ref.
    def exitProduct_ref(self, ctx:PBXProjParser.Product_refContext):
        pass


    # Enter a parse tree produced by PBXProjParser#container_portal.
    def enterContainer_portal(self, ctx:PBXProjParser.Container_portalContext):
        pass

    # Exit a parse tree produced by PBXProjParser#container_portal.
    def exitContainer_portal(self, ctx:PBXProjParser.Container_portalContext):
        pass


    # Enter a parse tree produced by PBXProjParser#proxy_type.
    def enterProxy_type(self, ctx:PBXProjParser.Proxy_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#proxy_type.
    def exitProxy_type(self, ctx:PBXProjParser.Proxy_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#remote_global_id_string.
    def enterRemote_global_id_string(self, ctx:PBXProjParser.Remote_global_id_stringContext):
        pass

    # Exit a parse tree produced by PBXProjParser#remote_global_id_string.
    def exitRemote_global_id_string(self, ctx:PBXProjParser.Remote_global_id_stringContext):
        pass


    # Enter a parse tree produced by PBXProjParser#remote_info.
    def enterRemote_info(self, ctx:PBXProjParser.Remote_infoContext):
        pass

    # Exit a parse tree produced by PBXProjParser#remote_info.
    def exitRemote_info(self, ctx:PBXProjParser.Remote_infoContext):
        pass


    # Enter a parse tree produced by PBXProjParser#file_encoding.
    def enterFile_encoding(self, ctx:PBXProjParser.File_encodingContext):
        pass

    # Exit a parse tree produced by PBXProjParser#file_encoding.
    def exitFile_encoding(self, ctx:PBXProjParser.File_encodingContext):
        pass


    # Enter a parse tree produced by PBXProjParser#comments.
    def enterComments(self, ctx:PBXProjParser.CommentsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#comments.
    def exitComments(self, ctx:PBXProjParser.CommentsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#explicit_file_type.
    def enterExplicit_file_type(self, ctx:PBXProjParser.Explicit_file_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#explicit_file_type.
    def exitExplicit_file_type(self, ctx:PBXProjParser.Explicit_file_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#last_known_file_type.
    def enterLast_known_file_type(self, ctx:PBXProjParser.Last_known_file_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#last_known_file_type.
    def exitLast_known_file_type(self, ctx:PBXProjParser.Last_known_file_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#include_in_index.
    def enterInclude_in_index(self, ctx:PBXProjParser.Include_in_indexContext):
        pass

    # Exit a parse tree produced by PBXProjParser#include_in_index.
    def exitInclude_in_index(self, ctx:PBXProjParser.Include_in_indexContext):
        pass


    # Enter a parse tree produced by PBXProjParser#indent_width.
    def enterIndent_width(self, ctx:PBXProjParser.Indent_widthContext):
        pass

    # Exit a parse tree produced by PBXProjParser#indent_width.
    def exitIndent_width(self, ctx:PBXProjParser.Indent_widthContext):
        pass


    # Enter a parse tree produced by PBXProjParser#tab_width.
    def enterTab_width(self, ctx:PBXProjParser.Tab_widthContext):
        pass

    # Exit a parse tree produced by PBXProjParser#tab_width.
    def exitTab_width(self, ctx:PBXProjParser.Tab_widthContext):
        pass


    # Enter a parse tree produced by PBXProjParser#uses_tabs.
    def enterUses_tabs(self, ctx:PBXProjParser.Uses_tabsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#uses_tabs.
    def exitUses_tabs(self, ctx:PBXProjParser.Uses_tabsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#wraps_lines.
    def enterWraps_lines(self, ctx:PBXProjParser.Wraps_linesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#wraps_lines.
    def exitWraps_lines(self, ctx:PBXProjParser.Wraps_linesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#platform_filter.
    def enterPlatform_filter(self, ctx:PBXProjParser.Platform_filterContext):
        pass

    # Exit a parse tree produced by PBXProjParser#platform_filter.
    def exitPlatform_filter(self, ctx:PBXProjParser.Platform_filterContext):
        pass


    # Enter a parse tree produced by PBXProjParser#platform_filters.
    def enterPlatform_filters(self, ctx:PBXProjParser.Platform_filtersContext):
        pass

    # Exit a parse tree produced by PBXProjParser#platform_filters.
    def exitPlatform_filters(self, ctx:PBXProjParser.Platform_filtersContext):
        pass


    # Enter a parse tree produced by PBXProjParser#children.
    def enterChildren(self, ctx:PBXProjParser.ChildrenContext):
        pass

    # Exit a parse tree produced by PBXProjParser#children.
    def exitChildren(self, ctx:PBXProjParser.ChildrenContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_install_path.
    def enterProduct_install_path(self, ctx:PBXProjParser.Product_install_pathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_install_path.
    def exitProduct_install_path(self, ctx:PBXProjParser.Product_install_pathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#repository_url.
    def enterRepository_url(self, ctx:PBXProjParser.Repository_urlContext):
        pass

    # Exit a parse tree produced by PBXProjParser#repository_url.
    def exitRepository_url(self, ctx:PBXProjParser.Repository_urlContext):
        pass


    # Enter a parse tree produced by PBXProjParser#requirement.
    def enterRequirement(self, ctx:PBXProjParser.RequirementContext):
        pass

    # Exit a parse tree produced by PBXProjParser#requirement.
    def exitRequirement(self, ctx:PBXProjParser.RequirementContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_package.
    def enterXc_package(self, ctx:PBXProjParser.Xc_packageContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_package.
    def exitXc_package(self, ctx:PBXProjParser.Xc_packageContext):
        pass


    # Enter a parse tree produced by PBXProjParser#package_product_dependencies.
    def enterPackage_product_dependencies(self, ctx:PBXProjParser.Package_product_dependenciesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#package_product_dependencies.
    def exitPackage_product_dependencies(self, ctx:PBXProjParser.Package_product_dependenciesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#name.
    def enterName(self, ctx:PBXProjParser.NameContext):
        pass

    # Exit a parse tree produced by PBXProjParser#name.
    def exitName(self, ctx:PBXProjParser.NameContext):
        pass


    # Enter a parse tree produced by PBXProjParser#path.
    def enterPath(self, ctx:PBXProjParser.PathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#path.
    def exitPath(self, ctx:PBXProjParser.PathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#source_tree.
    def enterSource_tree(self, ctx:PBXProjParser.Source_treeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#source_tree.
    def exitSource_tree(self, ctx:PBXProjParser.Source_treeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_action_mask.
    def enterBuild_action_mask(self, ctx:PBXProjParser.Build_action_maskContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_action_mask.
    def exitBuild_action_mask(self, ctx:PBXProjParser.Build_action_maskContext):
        pass


    # Enter a parse tree produced by PBXProjParser#files.
    def enterFiles(self, ctx:PBXProjParser.FilesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#files.
    def exitFiles(self, ctx:PBXProjParser.FilesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#run_only_for_deployment_postprocessing.
    def enterRun_only_for_deployment_postprocessing(self, ctx:PBXProjParser.Run_only_for_deployment_postprocessingContext):
        pass

    # Exit a parse tree produced by PBXProjParser#run_only_for_deployment_postprocessing.
    def exitRun_only_for_deployment_postprocessing(self, ctx:PBXProjParser.Run_only_for_deployment_postprocessingContext):
        pass


    # Enter a parse tree produced by PBXProjParser#reference_list.
    def enterReference_list(self, ctx:PBXProjParser.Reference_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#reference_list.
    def exitReference_list(self, ctx:PBXProjParser.Reference_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#any_string_list.
    def enterAny_string_list(self, ctx:PBXProjParser.Any_string_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#any_string_list.
    def exitAny_string_list(self, ctx:PBXProjParser.Any_string_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#non_quoted_strings_list.
    def enterNon_quoted_strings_list(self, ctx:PBXProjParser.Non_quoted_strings_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#non_quoted_strings_list.
    def exitNon_quoted_strings_list(self, ctx:PBXProjParser.Non_quoted_strings_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_configuration_list.
    def enterBuild_configuration_list(self, ctx:PBXProjParser.Build_configuration_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_configuration_list.
    def exitBuild_configuration_list(self, ctx:PBXProjParser.Build_configuration_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_phases.
    def enterBuild_phases(self, ctx:PBXProjParser.Build_phasesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_phases.
    def exitBuild_phases(self, ctx:PBXProjParser.Build_phasesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_rules.
    def enterBuild_rules(self, ctx:PBXProjParser.Build_rulesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_rules.
    def exitBuild_rules(self, ctx:PBXProjParser.Build_rulesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_arguments_string.
    def enterBuild_arguments_string(self, ctx:PBXProjParser.Build_arguments_stringContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_arguments_string.
    def exitBuild_arguments_string(self, ctx:PBXProjParser.Build_arguments_stringContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_tool_path.
    def enterBuild_tool_path(self, ctx:PBXProjParser.Build_tool_pathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_tool_path.
    def exitBuild_tool_path(self, ctx:PBXProjParser.Build_tool_pathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_working_directory.
    def enterBuild_working_directory(self, ctx:PBXProjParser.Build_working_directoryContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_working_directory.
    def exitBuild_working_directory(self, ctx:PBXProjParser.Build_working_directoryContext):
        pass


    # Enter a parse tree produced by PBXProjParser#pass_build_settings_in_environment.
    def enterPass_build_settings_in_environment(self, ctx:PBXProjParser.Pass_build_settings_in_environmentContext):
        pass

    # Exit a parse tree produced by PBXProjParser#pass_build_settings_in_environment.
    def exitPass_build_settings_in_environment(self, ctx:PBXProjParser.Pass_build_settings_in_environmentContext):
        pass


    # Enter a parse tree produced by PBXProjParser#dependencies.
    def enterDependencies(self, ctx:PBXProjParser.DependenciesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#dependencies.
    def exitDependencies(self, ctx:PBXProjParser.DependenciesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_name.
    def enterProduct_name(self, ctx:PBXProjParser.Product_nameContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_name.
    def exitProduct_name(self, ctx:PBXProjParser.Product_nameContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_reference.
    def enterProduct_reference(self, ctx:PBXProjParser.Product_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_reference.
    def exitProduct_reference(self, ctx:PBXProjParser.Product_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_type.
    def enterProduct_type(self, ctx:PBXProjParser.Product_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_type.
    def exitProduct_type(self, ctx:PBXProjParser.Product_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#line_ending.
    def enterLine_ending(self, ctx:PBXProjParser.Line_endingContext):
        pass

    # Exit a parse tree produced by PBXProjParser#line_ending.
    def exitLine_ending(self, ctx:PBXProjParser.Line_endingContext):
        pass


    # Enter a parse tree produced by PBXProjParser#xc_language_specification_identifier.
    def enterXc_language_specification_identifier(self, ctx:PBXProjParser.Xc_language_specification_identifierContext):
        pass

    # Exit a parse tree produced by PBXProjParser#xc_language_specification_identifier.
    def exitXc_language_specification_identifier(self, ctx:PBXProjParser.Xc_language_specification_identifierContext):
        pass


    # Enter a parse tree produced by PBXProjParser#plist_structure_definition_identifier.
    def enterPlist_structure_definition_identifier(self, ctx:PBXProjParser.Plist_structure_definition_identifierContext):
        pass

    # Exit a parse tree produced by PBXProjParser#plist_structure_definition_identifier.
    def exitPlist_structure_definition_identifier(self, ctx:PBXProjParser.Plist_structure_definition_identifierContext):
        pass


    # Enter a parse tree produced by PBXProjParser#attributes.
    def enterAttributes(self, ctx:PBXProjParser.AttributesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#attributes.
    def exitAttributes(self, ctx:PBXProjParser.AttributesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#last_swift_migration.
    def enterLast_swift_migration(self, ctx:PBXProjParser.Last_swift_migrationContext):
        pass

    # Exit a parse tree produced by PBXProjParser#last_swift_migration.
    def exitLast_swift_migration(self, ctx:PBXProjParser.Last_swift_migrationContext):
        pass


    # Enter a parse tree produced by PBXProjParser#default_build_system_type_for_workspace.
    def enterDefault_build_system_type_for_workspace(self, ctx:PBXProjParser.Default_build_system_type_for_workspaceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#default_build_system_type_for_workspace.
    def exitDefault_build_system_type_for_workspace(self, ctx:PBXProjParser.Default_build_system_type_for_workspaceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#last_swift_update_check.
    def enterLast_swift_update_check(self, ctx:PBXProjParser.Last_swift_update_checkContext):
        pass

    # Exit a parse tree produced by PBXProjParser#last_swift_update_check.
    def exitLast_swift_update_check(self, ctx:PBXProjParser.Last_swift_update_checkContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_targets_in_parallel.
    def enterBuild_targets_in_parallel(self, ctx:PBXProjParser.Build_targets_in_parallelContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_targets_in_parallel.
    def exitBuild_targets_in_parallel(self, ctx:PBXProjParser.Build_targets_in_parallelContext):
        pass


    # Enter a parse tree produced by PBXProjParser#last_testing_upgrade_check.
    def enterLast_testing_upgrade_check(self, ctx:PBXProjParser.Last_testing_upgrade_checkContext):
        pass

    # Exit a parse tree produced by PBXProjParser#last_testing_upgrade_check.
    def exitLast_testing_upgrade_check(self, ctx:PBXProjParser.Last_testing_upgrade_checkContext):
        pass


    # Enter a parse tree produced by PBXProjParser#last_upgrade_check.
    def enterLast_upgrade_check(self, ctx:PBXProjParser.Last_upgrade_checkContext):
        pass

    # Exit a parse tree produced by PBXProjParser#last_upgrade_check.
    def exitLast_upgrade_check(self, ctx:PBXProjParser.Last_upgrade_checkContext):
        pass


    # Enter a parse tree produced by PBXProjParser#organization_name.
    def enterOrganization_name(self, ctx:PBXProjParser.Organization_nameContext):
        pass

    # Exit a parse tree produced by PBXProjParser#organization_name.
    def exitOrganization_name(self, ctx:PBXProjParser.Organization_nameContext):
        pass


    # Enter a parse tree produced by PBXProjParser#target_attributes.
    def enterTarget_attributes(self, ctx:PBXProjParser.Target_attributesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#target_attributes.
    def exitTarget_attributes(self, ctx:PBXProjParser.Target_attributesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#target_attribute.
    def enterTarget_attribute(self, ctx:PBXProjParser.Target_attributeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#target_attribute.
    def exitTarget_attribute(self, ctx:PBXProjParser.Target_attributeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#created_on_tools_version.
    def enterCreated_on_tools_version(self, ctx:PBXProjParser.Created_on_tools_versionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#created_on_tools_version.
    def exitCreated_on_tools_version(self, ctx:PBXProjParser.Created_on_tools_versionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#test_target_id.
    def enterTest_target_id(self, ctx:PBXProjParser.Test_target_idContext):
        pass

    # Exit a parse tree produced by PBXProjParser#test_target_id.
    def exitTest_target_id(self, ctx:PBXProjParser.Test_target_idContext):
        pass


    # Enter a parse tree produced by PBXProjParser#development_team.
    def enterDevelopment_team(self, ctx:PBXProjParser.Development_teamContext):
        pass

    # Exit a parse tree produced by PBXProjParser#development_team.
    def exitDevelopment_team(self, ctx:PBXProjParser.Development_teamContext):
        pass


    # Enter a parse tree produced by PBXProjParser#development_team_name.
    def enterDevelopment_team_name(self, ctx:PBXProjParser.Development_team_nameContext):
        pass

    # Exit a parse tree produced by PBXProjParser#development_team_name.
    def exitDevelopment_team_name(self, ctx:PBXProjParser.Development_team_nameContext):
        pass


    # Enter a parse tree produced by PBXProjParser#provisioning_style.
    def enterProvisioning_style(self, ctx:PBXProjParser.Provisioning_styleContext):
        pass

    # Exit a parse tree produced by PBXProjParser#provisioning_style.
    def exitProvisioning_style(self, ctx:PBXProjParser.Provisioning_styleContext):
        pass


    # Enter a parse tree produced by PBXProjParser#compatibility_version.
    def enterCompatibility_version(self, ctx:PBXProjParser.Compatibility_versionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#compatibility_version.
    def exitCompatibility_version(self, ctx:PBXProjParser.Compatibility_versionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#development_region.
    def enterDevelopment_region(self, ctx:PBXProjParser.Development_regionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#development_region.
    def exitDevelopment_region(self, ctx:PBXProjParser.Development_regionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#has_scanned_for_encodings.
    def enterHas_scanned_for_encodings(self, ctx:PBXProjParser.Has_scanned_for_encodingsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#has_scanned_for_encodings.
    def exitHas_scanned_for_encodings(self, ctx:PBXProjParser.Has_scanned_for_encodingsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#known_regions.
    def enterKnown_regions(self, ctx:PBXProjParser.Known_regionsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#known_regions.
    def exitKnown_regions(self, ctx:PBXProjParser.Known_regionsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#main_group.
    def enterMain_group(self, ctx:PBXProjParser.Main_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#main_group.
    def exitMain_group(self, ctx:PBXProjParser.Main_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#product_ref_group.
    def enterProduct_ref_group(self, ctx:PBXProjParser.Product_ref_groupContext):
        pass

    # Exit a parse tree produced by PBXProjParser#product_ref_group.
    def exitProduct_ref_group(self, ctx:PBXProjParser.Product_ref_groupContext):
        pass


    # Enter a parse tree produced by PBXProjParser#package_references.
    def enterPackage_references(self, ctx:PBXProjParser.Package_referencesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#package_references.
    def exitPackage_references(self, ctx:PBXProjParser.Package_referencesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#project_dir_path.
    def enterProject_dir_path(self, ctx:PBXProjParser.Project_dir_pathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#project_dir_path.
    def exitProject_dir_path(self, ctx:PBXProjParser.Project_dir_pathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#project_references.
    def enterProject_references(self, ctx:PBXProjParser.Project_referencesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#project_references.
    def exitProject_references(self, ctx:PBXProjParser.Project_referencesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#project_root.
    def enterProject_root(self, ctx:PBXProjParser.Project_rootContext):
        pass

    # Exit a parse tree produced by PBXProjParser#project_root.
    def exitProject_root(self, ctx:PBXProjParser.Project_rootContext):
        pass


    # Enter a parse tree produced by PBXProjParser#targets.
    def enterTargets(self, ctx:PBXProjParser.TargetsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#targets.
    def exitTargets(self, ctx:PBXProjParser.TargetsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#input_file_list_paths.
    def enterInput_file_list_paths(self, ctx:PBXProjParser.Input_file_list_pathsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#input_file_list_paths.
    def exitInput_file_list_paths(self, ctx:PBXProjParser.Input_file_list_pathsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#input_paths.
    def enterInput_paths(self, ctx:PBXProjParser.Input_pathsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#input_paths.
    def exitInput_paths(self, ctx:PBXProjParser.Input_pathsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#output_file_list_paths.
    def enterOutput_file_list_paths(self, ctx:PBXProjParser.Output_file_list_pathsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#output_file_list_paths.
    def exitOutput_file_list_paths(self, ctx:PBXProjParser.Output_file_list_pathsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#output_paths.
    def enterOutput_paths(self, ctx:PBXProjParser.Output_pathsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#output_paths.
    def exitOutput_paths(self, ctx:PBXProjParser.Output_pathsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#shell_path.
    def enterShell_path(self, ctx:PBXProjParser.Shell_pathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#shell_path.
    def exitShell_path(self, ctx:PBXProjParser.Shell_pathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#shell_script.
    def enterShell_script(self, ctx:PBXProjParser.Shell_scriptContext):
        pass

    # Exit a parse tree produced by PBXProjParser#shell_script.
    def exitShell_script(self, ctx:PBXProjParser.Shell_scriptContext):
        pass


    # Enter a parse tree produced by PBXProjParser#show_env_vars_in_log.
    def enterShow_env_vars_in_log(self, ctx:PBXProjParser.Show_env_vars_in_logContext):
        pass

    # Exit a parse tree produced by PBXProjParser#show_env_vars_in_log.
    def exitShow_env_vars_in_log(self, ctx:PBXProjParser.Show_env_vars_in_logContext):
        pass


    # Enter a parse tree produced by PBXProjParser#target.
    def enterTarget(self, ctx:PBXProjParser.TargetContext):
        pass

    # Exit a parse tree produced by PBXProjParser#target.
    def exitTarget(self, ctx:PBXProjParser.TargetContext):
        pass


    # Enter a parse tree produced by PBXProjParser#target_proxy.
    def enterTarget_proxy(self, ctx:PBXProjParser.Target_proxyContext):
        pass

    # Exit a parse tree produced by PBXProjParser#target_proxy.
    def exitTarget_proxy(self, ctx:PBXProjParser.Target_proxyContext):
        pass


    # Enter a parse tree produced by PBXProjParser#file_type.
    def enterFile_type(self, ctx:PBXProjParser.File_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#file_type.
    def exitFile_type(self, ctx:PBXProjParser.File_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#remote_ref.
    def enterRemote_ref(self, ctx:PBXProjParser.Remote_refContext):
        pass

    # Exit a parse tree produced by PBXProjParser#remote_ref.
    def exitRemote_ref(self, ctx:PBXProjParser.Remote_refContext):
        pass


    # Enter a parse tree produced by PBXProjParser#base_configuration_reference.
    def enterBase_configuration_reference(self, ctx:PBXProjParser.Base_configuration_referenceContext):
        pass

    # Exit a parse tree produced by PBXProjParser#base_configuration_reference.
    def exitBase_configuration_reference(self, ctx:PBXProjParser.Base_configuration_referenceContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_settings.
    def enterBuild_settings(self, ctx:PBXProjParser.Build_settingsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_settings.
    def exitBuild_settings(self, ctx:PBXProjParser.Build_settingsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#dst_path.
    def enterDst_path(self, ctx:PBXProjParser.Dst_pathContext):
        pass

    # Exit a parse tree produced by PBXProjParser#dst_path.
    def exitDst_path(self, ctx:PBXProjParser.Dst_pathContext):
        pass


    # Enter a parse tree produced by PBXProjParser#dst_subfolder_spec.
    def enterDst_subfolder_spec(self, ctx:PBXProjParser.Dst_subfolder_specContext):
        pass

    # Exit a parse tree produced by PBXProjParser#dst_subfolder_spec.
    def exitDst_subfolder_spec(self, ctx:PBXProjParser.Dst_subfolder_specContext):
        pass


    # Enter a parse tree produced by PBXProjParser#project_references_list.
    def enterProject_references_list(self, ctx:PBXProjParser.Project_references_listContext):
        pass

    # Exit a parse tree produced by PBXProjParser#project_references_list.
    def exitProject_references_list(self, ctx:PBXProjParser.Project_references_listContext):
        pass


    # Enter a parse tree produced by PBXProjParser#project_references_list_element.
    def enterProject_references_list_element(self, ctx:PBXProjParser.Project_references_list_elementContext):
        pass

    # Exit a parse tree produced by PBXProjParser#project_references_list_element.
    def exitProject_references_list_element(self, ctx:PBXProjParser.Project_references_list_elementContext):
        pass


    # Enter a parse tree produced by PBXProjParser#key_value.
    def enterKey_value(self, ctx:PBXProjParser.Key_valueContext):
        pass

    # Exit a parse tree produced by PBXProjParser#key_value.
    def exitKey_value(self, ctx:PBXProjParser.Key_valueContext):
        pass


    # Enter a parse tree produced by PBXProjParser#build_configurations.
    def enterBuild_configurations(self, ctx:PBXProjParser.Build_configurationsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#build_configurations.
    def exitBuild_configurations(self, ctx:PBXProjParser.Build_configurationsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#default_configuration_is_visible.
    def enterDefault_configuration_is_visible(self, ctx:PBXProjParser.Default_configuration_is_visibleContext):
        pass

    # Exit a parse tree produced by PBXProjParser#default_configuration_is_visible.
    def exitDefault_configuration_is_visible(self, ctx:PBXProjParser.Default_configuration_is_visibleContext):
        pass


    # Enter a parse tree produced by PBXProjParser#default_configuration_name.
    def enterDefault_configuration_name(self, ctx:PBXProjParser.Default_configuration_nameContext):
        pass

    # Exit a parse tree produced by PBXProjParser#default_configuration_name.
    def exitDefault_configuration_name(self, ctx:PBXProjParser.Default_configuration_nameContext):
        pass


    # Enter a parse tree produced by PBXProjParser#settings.
    def enterSettings(self, ctx:PBXProjParser.SettingsContext):
        pass

    # Exit a parse tree produced by PBXProjParser#settings.
    def exitSettings(self, ctx:PBXProjParser.SettingsContext):
        pass


    # Enter a parse tree produced by PBXProjParser#system_capabilities.
    def enterSystem_capabilities(self, ctx:PBXProjParser.System_capabilitiesContext):
        pass

    # Exit a parse tree produced by PBXProjParser#system_capabilities.
    def exitSystem_capabilities(self, ctx:PBXProjParser.System_capabilitiesContext):
        pass


    # Enter a parse tree produced by PBXProjParser#current_version.
    def enterCurrent_version(self, ctx:PBXProjParser.Current_versionContext):
        pass

    # Exit a parse tree produced by PBXProjParser#current_version.
    def exitCurrent_version(self, ctx:PBXProjParser.Current_versionContext):
        pass


    # Enter a parse tree produced by PBXProjParser#version_group_type.
    def enterVersion_group_type(self, ctx:PBXProjParser.Version_group_typeContext):
        pass

    # Exit a parse tree produced by PBXProjParser#version_group_type.
    def exitVersion_group_type(self, ctx:PBXProjParser.Version_group_typeContext):
        pass


    # Enter a parse tree produced by PBXProjParser#class_prefix.
    def enterClass_prefix(self, ctx:PBXProjParser.Class_prefixContext):
        pass

    # Exit a parse tree produced by PBXProjParser#class_prefix.
    def exitClass_prefix(self, ctx:PBXProjParser.Class_prefixContext):
        pass


    # Enter a parse tree produced by PBXProjParser#any_string.
    def enterAny_string(self, ctx:PBXProjParser.Any_stringContext):
        pass

    # Exit a parse tree produced by PBXProjParser#any_string.
    def exitAny_string(self, ctx:PBXProjParser.Any_stringContext):
        pass



del PBXProjParser